﻿
	// OSHelper_ExportToAME_v1.1
	// created by Paul Tuersley
	// May 2017
	
	// This script functions as a helper script for use with pt_OpenSesame and pt_OpenSesame Server only.

	function OSHelperScript_Setup() {
		// This function will be called by pt_OpenSesame when exporting the helper script options
		// Set up any user editable options you want included in the export, including any default values
		//if (OSHelperScript_Data.JSON) {} // Use this to query if OpenSesame is exporting JSON format. Values must be strings for TSV, CSV export but you can set up arrays for JSON exports
		//OSHelperScript_Data.PostRender = true;	// By default a helper script is exported as being applied before a render. Use this to default it to being used as a post render script.

		if (parseFloat(app.version) >= 14) {
			OSHelperScript_Data.PostRender = true;
			OSHelperScript_Data.AllQueued = true;
		}

		OSHelperScript_Data.CompID = "undefined";
	}


	function OSHelperScript_Run() {
		
		// if AE supports it (CC 2017 v14.0 or later) and user has chosen to export all queued items to AME
		if (parseFloat(app.version) >= 14 && OSHelperScript_Data.AllQueued != undefined && (OSHelperScript_Data.AllQueued == true || OSHelperScript_Data.AllQueued == "true")) {
			if (app.project.renderQueue.canQueueInAME == true) {
		        app.project.renderQueue.queueInAME(true);
				OSHelperScript_Data.Message = "Queued items were sent to AME";
			} else OSHelperScript_Data.Message = "Error - There were no queued items to send to AME";
		
   	 } else {

			var theComp, x;
			
			if (OSHelperScript_Data.CompID == undefined || OSHelperScript_Data.CompID == "undefined") {
				// Use OSHelperScript_Data.Message to store a string only, containing any message you want OpenSesame to add to the log file. Including the word "error" will cause it to be flagged as such by OpenSesame.
				OSHelperScript_Data.Message = "Error - No CompID specified";
				return;
			}
		
			for (x = 1; x <= app.project.numItems; x++) {	// look for the comp with the specified ID
				if (app.project.item(x).id == OSHelperScript_Data.CompID && app.project.item(x) instanceof CompItem) {
					theComp = app.project.item(x);
					break;
				}
			}
		
			if (theComp == null) {
				OSHelperScript_Data.Message = "Error - No comp found with ID " + OSHelperScript_Data.CompID;
				return;
			}
		
			// ensure all project items are deselected, then select the specified comp
			while (app.project.selection.length > 0) {
				app.project.selection[0].selected = false;
			}
			theComp.selected = true;
			
			// call menu command for exporting to AME
			app.executeCommand(app.findMenuCommandId("Add to Adobe Media Encoder Queue...")); 
			
			// send completion message for log file
			OSHelperScript_Data.Message = theComp.name + " (CompID:" + OSHelperScript_Data.CompID + ") was exported to AME";
		}
	}
		
		
		
					
				
				